@@ -616,11 +616,43 @@ class Connector:
     def configure_playground(self,
                              width: Optional[Number] = None,
                              height: Optional[Number] = None,
+                             origin_x: Optional[Number] = None,
+                             origin_y: Optional[Number] = None,
                              shift_x: Optional[Number] = None,
                              shift_y: Optional[Number] = None,
                              color: Optional[Union[Colors, str]] = None,
                              images: Optional[Union[Path, str]] = None,
                              **delivery_opts):
+        '''
+        Optional
+        --------
+        width : Number
+            width of the playground (this has no units - it defines your playground unit)
+
+        height : Number
+            height of the playground (this has no units - it defines your playground unit)
+
+        origin_x : Number
+            the x coordinate of the origin of your playground. By default it is in the lower left corner at 0, 0. You can define it in
+            your playground coordinates.
+
+        origin_y : Number
+            the y coordinate of the origin of your playground. By default it is in the lower left corner at 0, 0. You can define it in
+            your playground coordinates.
+
+        shift_x : Number
+            How many units should the playground be shifted horizontally? Same as the negative value of origin_x.
+            Only one of both should be set
+
+        shift_y : Number
+            How many units should the playground be shifted vertically? Same as the negative value of origin_y
+            Only one of both should be set
+
+        '''
+        if origin_x is not None:
+            shift_x = -origin_x
+        if origin_y is not None:
+            shift_y = -origin_y
         raw_images = []
         if images is not None:
             images = Path(images)
@@ -677,6 +709,8 @@ class Connector:
                 height: Optional[Number] = None,
                 pos_x: Optional[Number] = None,
                 pos_y: Optional[Number] = None,
+                size: Optional[Number] = None,
+                radius: Optional[Number] = None,
                 anchor: Optional[Tuple[Number, Number]] = None,
                 reset_time: Optional[Number] = None,
                 speed: Optional[Number] = None,
@@ -709,6 +743,12 @@ class Connector:
             pos_y : Number
                 the y position in playground units
 
+            size : Number
+                set the width and height to the same size
+
+            radius : Number
+                set the width and height to 2 * radius
+
             anchor : Tuple[Number, Number]
                 the anchor (center) of the sprite: range from 0 (left/bottom) to 1 (right/top)
 
@@ -748,6 +788,14 @@ class Connector:
             time_span : Number
                 the time a sprite lives
             '''
+            if size is not None:
+                width = size
+                height = size
+
+            if radius is not None:
+                width = radius * 2
+                height = radius * 2
+
             s = {
                 'id': id if id is not None else f'sprite{randint(10000, 99999)}',
                 'clickable': clickable,
@@ -795,6 +843,8 @@ class Connector:
             )
 
     update_sprites = add_sprites
+    add_objects = add_sprites
+    update_objects = add_sprites
 
     def add_circle(
             self,
@@ -880,8 +930,8 @@ class Connector:
             color=color,
             direction=direction,
             distance=distance,
-            height=radius * 2,
-            width=radius * 2,
+            height=radius * 2 if radius is not None else None,
+            width=radius * 2 if radius is not None else None,
             pos_x=pos_x,
             pos_y=pos_y,
             anchor=anchor,
@@ -1418,6 +1468,8 @@ class Connector:
             **delivery_opts
         )
 
+    remove_object = remove_sprite
+
     update_sprite = add_sprite
 
     def add_line(
